==> webkit2gtk_2.42.4.orig.tar.xz: webkitgtk-2.42.4/Source/WebCore/Modules/speech/LocalDOMWindowSpeechSynthesis.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(SPEECH_SYNTHESIS)

#include "LocalDOMWindowProperty.h"
#include "SpeechSynthesis.h"
#include "Supplementable.h"

namespace WebCore {
    
class LocalDOMWindow;

class LocalDOMWindowSpeechSynthesis : public Supplement<LocalDOMWindow>, public LocalDOMWindowProperty {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit LocalDOMWindowSpeechSynthesis(LocalDOMWindow*);
    virtual ~LocalDOMWindowSpeechSynthesis();
    
    WEBCORE_EXPORT static SpeechSynthesis* speechSynthesis(LocalDOMWindow&);
    static LocalDOMWindowSpeechSynthesis* from(LocalDOMWindow*);
    
private:
    SpeechSynthesis* speechSynthesis();
    static const char* supplementName();
    
    RefPtr<SpeechSynthesis> m_speechSynthesis;
};

} // namespace WebCore

#endif // ENABLE(SPEECH_SYNTHESIS)

==> webkit2gtk_2.44.0.orig.tar.xz: webkitgtk-2.44.0/Source/WebCore/Modules/speech/LocalDOMWindowSpeechSynthesis.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(SPEECH_SYNTHESIS)

#include "LocalDOMWindowProperty.h"
#include "SpeechSynthesis.h"
#include "Supplementable.h"

namespace WebCore {
    
class LocalDOMWindow;

class LocalDOMWindowSpeechSynthesis : public Supplement<LocalDOMWindow>, public LocalDOMWindowProperty {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit LocalDOMWindowSpeechSynthesis(LocalDOMWindow*);
    virtual ~LocalDOMWindowSpeechSynthesis();
    
    WEBCORE_EXPORT static SpeechSynthesis* speechSynthesis(LocalDOMWindow&);
    static LocalDOMWindowSpeechSynthesis* from(LocalDOMWindow*);
    
private:
    SpeechSynthesis* speechSynthesis();
    static ASCIILiteral supplementName();
    
    RefPtr<SpeechSynthesis> m_speechSynthesis;
};

} // namespace WebCore

#endif // ENABLE(SPEECH_SYNTHESIS)
